
// GetTopic.java
// Andrew Davison, ad@coe.psu.ac.th, July 2023

/* Search for English language articles on the topic
   supplied on the command line. If a number
   is included then that article's URL is loaded into
   a browser.

  Usage:
    > compile GetTopic.java
    > run GetTopic <topic> [<story num>]
  e.g. 
    > run GetTopic "tom cruise"
    > run ShowTopic "tom cruise" 3

  More info: https://newsapi.org/docs/endpoints/everything
*/

import java.util.*;


public class GetTopic
{

  public static void main(String[] args)
  {
    int newsItem = -1;

    if ((args.length == 0) || (args.length > 2)) {
      System.out.println("Usage: run GetTopic <topic> [<story num>]");
      return;
    }

    String topic = NewsUtils.encode(args[0]);

    if (args.length == 2)
      newsItem = NewsUtils.getInt(args[1]);

    String request = "https://newsapi.org/v2/everything?" +
                       "q=" + topic + "&" +
                       "language=en&" + 
                       "sortBy=relevancy";
    News news = NewsUtils.getNews(request);
    if (news != null) {
      if (newsItem != -1)
        NewsUtils.showArticle(news, newsItem);
      else
        NewsUtils.listNews(news);
    }
  } /* main */

}  // end of GetTopic class

